#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

setup(
    name='zoo',
    version='0.1a0',
    packages=find_packages(),
    install_requires=[],

    author='omsobliga',
    author_email='omsobliga@gmail.com',
    description='Zoo is a rpc framework for Python',
    license='MIT',
    url='https://github.com/omsobliga/zoo'
)
